===============================
Python client for dataquality.pl
===============================


.. image:: https://img.shields.io/pypi/v/dq_client.svg
        :target: https://pypi.python.org/pypi/dq-client

.. image:: https://img.shields.io/travis/Algolytics/dq_client.svg
        :target: https://travis-ci.org/Algolytics/dq_client

.. image:: https://readthedocs.org/projects/dq-client/badge/?version=latest
        :target: https://dq-client.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/algolytics/dq_client/shield.svg
     :target: https://pyup.io/repos/github/algolytics/dq_client/
     :alt: Updates


Python library which allows to use http://dataquality.pl in the easy way.


* Free software: Apache Software License 2.0
* Documentation: https://dq-client.readthedocs.io.


Features
--------

* Full API client
* Automatic encoding file conversion

Credits
---------

This package was created by Algolytics_ dev team.

.. _Algolytics: http://algolytics.com

